@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -47,7 +48,7 @@
 #include "Client.hxx"
 #include <vcl/svapp.hxx>
 #include <vcl/tabpage.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <com/sun/star/drawing/framework/ResourceId.hpp>
 #include <com/sun/star/drawing/framework/XControllerManager.hpp>
@@ -196,7 +197,7 @@ void ViewTabBar::disposing (void)
     }
 
     {
-        const ::vos::OGuard aSolarGuard (Application::GetSolarMutex());
+        const SolarMutexGuard aSolarGuard;
         // Set all references to the one tab page to NULL and delete the page.
         for (USHORT nIndex=0; nIndex<mpTabControl->GetPageCount(); ++nIndex)
             mpTabControl->SetTabPage(nIndex, NULL);
@@ -320,7 +321,7 @@ void SAL_CALL ViewTabBar::addTabBarButtonAfter (
     const TabBarButton& rAnchor)
     throw (::com::sun::star::uno::RuntimeException)
 {
-    const ::vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     AddTabBarButton(rButton, rAnchor);
 }
 
@@ -330,7 +331,7 @@ void SAL_CALL ViewTabBar::addTabBarButtonAfter (
 void SAL_CALL ViewTabBar::appendTabBarButton (const TabBarButton& rButton)
     throw (::com::sun::star::uno::RuntimeException)
 {
-    const ::vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     AddTabBarButton(rButton);
 }
 
@@ -339,7 +340,7 @@ void SAL_CALL ViewTabBar::appendTabBarButton (const TabBarButton& rButton)
 void SAL_CALL ViewTabBar::removeTabBarButton (const TabBarButton& rButton)
     throw (::com::sun::star::uno::RuntimeException)
 {
-    const ::vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     RemoveTabBarButton(rButton);
 }
 
@@ -349,7 +350,7 @@ void SAL_CALL ViewTabBar::removeTabBarButton (const TabBarButton& rButton)
 sal_Bool SAL_CALL ViewTabBar::hasTabBarButton (const TabBarButton& rButton)
     throw (::com::sun::star::uno::RuntimeException)
 {
-    const ::vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     return HasTabBarButton(rButton);
 }
 
@@ -359,7 +360,7 @@ sal_Bool SAL_CALL ViewTabBar::hasTabBarButton (const TabBarButton& rButton)
 Sequence<TabBarButton> SAL_CALL ViewTabBar::getTabBarButtons (void)
     throw (::com::sun::star::uno::RuntimeException)
 {
-    const ::vos::OGuard aSolarGuard (Application::GetSolarMutex());
+    const SolarMutexGuard aSolarGuard;
     return GetTabBarButtons();
 }
 
@@ -393,7 +394,7 @@ const Sequence<sal_Int8>& ViewTabBar::getUnoTunnelId (void)
     static Sequence<sal_Int8>* pSequence = NULL;
     if (pSequence == NULL)
     {
-        const ::vos::OGuard aSolarGuard (Application::GetSolarMutex());
+        const SolarMutexGuard aSolarGuard;
         if (pSequence == NULL)
         {
             static ::com::sun::star::uno::Sequence<sal_Int8> aSequence (16);
@@ -714,3 +715,5 @@ void TabBarControl::ActivatePage (void)
 }
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
